function res = tut_patch_extract(varargin)
% Di 11. Aug 11:32:09 CEST 2015
%{

	INPUT
		target_size - size of extracted patch
		alpha		- rotation in deg
		wobble		- strength of wobble
		alt_image   - grid image

	OUTPUT
%}

	opt_args = {[120, 200], 0, 0, 0};
	opt_args(1:length(varargin)) = varargin;
	[target_size, alpha, wobble, alt_image] = opt_args{:};

	alpha = alpha/360 * 2*pi;

	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% load data
	%cd /home/maid/phd/trunk/matlab/tutorial

	if(alt_image == 0)
		im = imread('cat_sir.jpg');
		im = single(im);
		im = im / max(im(:));
	else

		%alt: grid
		im = single(zeros(500,500));
		im(1:20:end,:) = 1;
		im(:,1:20:end) = 1;
		im = 1-im;
	end

	%get center of patch
	figure(1), imshow(im);
	[x,y] = ginput(1);
	hold on;
	plot(x,y,'xr', 'MarkerSize', 10);


R = [	cos(alpha), -sin(alpha), 0;
		sin(alpha), cos(alpha), 0;
		0, 0, 1];

%to origin
M1 = [	1 0 -y;
		0 1 -x;
		0 0 1];

%origin to center of target
M2 = [	1 0 target_size(1)/2;
		0 1 target_size(2)/2; 
		0 0 1];

M = pinv(M2*R*M1);


	%target coordinates for "readout" with interpn
	[X,Y] = ndgrid(1:target_size(1), 1:target_size(2));

	XT = M(1,1)*X + M(1,2)*Y + M(1,3);
	YT = M(2,1)*X + M(2,2)*Y + M(2,3);


%wobble
u = randn(3,3);
v = randn(3,3);
U = imresize(u,size(X),'bicubic');
V = imresize(v,size(X),'bicubic');

%  put all together
XT = M(1,1)*X + M(1,2)*Y + M(1,3) + wobble * U;
YT = M(2,1)*X + M(2,2)*Y + M(2,3) + wobble * V;


%mirror?
XT(XT < 1) = 2 - XT(XT < 1);
YT(YT < 1) = 2 - YT(YT < 1);
XT(XT > size(im,1)) = 2*size(im,1) - XT( XT > size(im,1));
YT(YT > size(im,2)) = 2*size(im,2) - YT( YT > size(im,2));


	%extraction
	target = zeros([target_size, size(im,3)]);
	for ch = 1:size(im,3)
		target(:,:,ch) = interpn(im(:,:,ch), XT, YT, 'bicubic',0);
	end


	%show region in in source
	corners = bsxfun(@times, target_size', combvec([0 1], [0 1]));
	corners(corners==0) = 1;
	corners = corners(:, [1 2 4 3]);%for polygon

	cs = M * [corners; ones(1, size(corners,2))];
	cs(:,end+1) = cs(:,1); %for polygon

	figure(1), plot(cs(2,:), cs(1,:), '-r', 'LineWidth', 2);
	figure(2), imshow(target);
end
